ChipStyle class

Constructors

ChipStyle({double? size, Color? background = Colors.blue, Color? color, bool? isHexagon, bool? drawHexagon, bool? convexBridge, NotchSmoothness? notchSmoothness})
const

Properties

background → Color?
final
color → Color?
final
convexBridge → bool?
final
drawHexagon → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
isHexagon → bool?
final
notchSmoothness → NotchSmoothness?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited